@@ -45,7 +45,7 @@ class ProminenceClient(object):
         else:
             raise exceptions.TokenError('Unable to obtain a token')
 
-    def list_jobs(self, completed=False, all=False, num=1, constraint=None):
+    def list_jobs(self, completed=False, all=False, num=1, constraint=None, workflow_id=None):
         """
         List running/idle jobs or completed jobs
         """
@@ -59,6 +59,10 @@ class ProminenceClient(object):
             params['all'] = 'true'
         if constraint:
             params['constraint'] = constraint
+        if workflow_id:
+            params['id'] = workflow_id
+            params['workflow'] = 'true'
+            params['num'] = -1
 
         try:
             response = requests.get(self._url + '/jobs', params=params, timeout=self._timeout, headers=self._headers, verify=self._verify)
@@ -206,7 +210,7 @@ class ProminenceClient(object):
         except requests.exceptions.RequestException as e:
             raise exceptions.ConnectionError(e)
 
-        if response.status_code == 200:
+        if response.status_code == 200 or response.status_code == 204:
             return True
         elif response.status_code == 401:
             raise exceptions.AuthenticationError()
